@@ -8,7 +8,7 @@ from django.templatetags.static import static
 register = template.Library()
 
 @register.simple_tag(takes_context=True)
-def script_config(obj):
+def script_config(context, obj):
 	if not hasattr(request, "script_config"):
 		setattr(request, "script_config", {})
 	request.script_config.update(obj)
